# data_science

This repository for our Data Science work. 

Currently we are working in Fraud Detection with a Data from Kaggale. 

Demo to show the process how it works.

Demo on 10/21/2019

Demo on 11/13/2019

Demo on 11/13/2019 - 2

ISDS-153 For testing -

Testing 2019/12/13
ISDS-153 Testing 2020/01/29

Testing 2020/3/3

Testing 2020/5/21

